@@ -13,6 +13,3 @@
 #
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
-
-from .channel import *
-from .channel_instances import *
