@@ -66,7 +66,7 @@ class Channel(object):
                            **kwargs) -> CONSUMER_CLASS:
         """
         Create an appropriate consumer instance for this channel and add it to the consumer list
-        Should end by calling '__check_producers_state'
+        Should end by calling '_check_producers_state'
         :param callback: method that should be called when consuming the queue
         :param consumer_filters: the consumer filters
         :param size: queue size, default 0
@@ -75,11 +75,11 @@ class Channel(object):
         :return: consumer instance created
         """
         consumer = internal_consumer if internal_consumer else self.CONSUMER_CLASS(callback)
-        await self.__add_new_consumer_and_run(consumer, consumer_filters)
-        await self.__check_producers_state()
+        await self._add_new_consumer_and_run(consumer, consumer_filters)
+        await self._check_producers_state()
         return consumer
 
-    async def __add_new_consumer_and_run(self, consumer: CONSUMER_CLASS, consumer_filters: dict, **kwargs) -> None:
+    async def _add_new_consumer_and_run(self, consumer: CONSUMER_CLASS, consumer_filters: dict, **kwargs) -> None:
         """
         Should be called by 'new_consumer' to add the consumer to self.consumers and call 'consumer.run()'
         :param consumer: the consumer to add
@@ -103,7 +103,7 @@ class Channel(object):
         self.consumers.append(consumer_filters)
 
     def get_consumer_from_filters(self, consumer_filters) -> list:
-        return self.__filter_consumers(consumer_filters)
+        return self._filter_consumers(consumer_filters)
 
     def get_consumers(self) -> list:
         """
@@ -113,7 +113,7 @@ class Channel(object):
         """
         return [consumer[self.INSTANCE_KEY] for consumer in self.consumers]
 
-    def __filter_consumers(self, consumer_filters) -> list:
+    def _filter_consumers(self, consumer_filters) -> list:
         """
         Returns the consumers that match the selection
         Returns all consumer instances if consumer_filter is empty
@@ -122,9 +122,9 @@ class Channel(object):
         """
         return [consumer[self.INSTANCE_KEY]
                 for consumer in self.consumers
-                if self.__check_filters(consumer, consumer_filters)]
+                if self._check_filters(consumer, consumer_filters)]
 
-    def __check_filters(self, consumer_filters, expected_filters) -> bool:
+    def _check_filters(self, consumer_filters, expected_filters) -> bool:
         """
         Checks if the consumer match the specified filters
         Returns True if expected_filters is empty
@@ -139,7 +139,7 @@ class Channel(object):
     async def remove_consumer(self, consumer: CONSUMER_CLASS, **kwargs) -> None:
         """
         Should be overwritten according to the class needs
-        Should end by calling '__check_producers_state' and then 'consumer.stop'
+        Should end by calling '_check_producers_state' and then 'consumer.stop'
         :param consumer: consumer instance to remove from consumers list
         :param kwargs: consumers list filter params
         :return: None
@@ -147,10 +147,10 @@ class Channel(object):
         for c in self.consumers:
             if consumer == c[self.INSTANCE_KEY]:
                 self.consumers.remove(c)
-                await self.__check_producers_state()
+                await self._check_producers_state()
                 await consumer.stop()
 
-    async def __check_producers_state(self) -> None:
+    async def _check_producers_state(self) -> None:
         """
         Checks if producers should be paused or resumed after a consumer addition or removal
         :return: None
@@ -217,6 +217,12 @@ class Channel(object):
         for producer in self.get_producers():
             await producer.stop()
 
+    def flush(self) -> None:
+        if self.internal_producer is not None:
+            self.internal_producer.channel = None
+        for producer in self.get_producers():
+            producer.channel = None
+
     async def run(self) -> None:
         """
         Call each registered consumers run method
@@ -248,18 +254,18 @@ class Channel(object):
         return self.internal_producer
 
 
-def set_chan(chan, name) -> None:
+def set_chan(chan, name) -> Channel:
     """
     Set a new Channel instance in the channels list according to channel name
     :param chan: new Channel instance
     :param name: name of the channel
-    :return: None
+    :return: the channel instance if succeed else raise a ValueError
     """
-    chan_name = chan.get_name() if name else name
+    chan_name = name if name else chan.get_name()
     if chan_name not in ChannelInstances.instance().channels:
         ChannelInstances.instance().channels[chan_name] = chan
-    else:
-        raise ValueError(f"Channel {chan_name} already exists.")
+        return chan
+    raise ValueError(f"Channel {chan_name} already exists.")
 
 
 def del_chan(name) -> None:
