@@ -14,13 +14,13 @@
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
 
-from octobot_commons.singleton import Singleton
+from octobot_commons.singleton.singleton_class import Singleton
 
 
-@Singleton
-class ChannelInstances:
+class ChannelInstances(Singleton):
     """
     Singleton that contains Channel instances
     """
+
     def __init__(self):
         self.channels = {}
