@@ -14,7 +14,7 @@
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
 import asyncio
-from asyncio import Queue
+from asyncio import Queue, CancelledError
 
 from octobot_commons.logging.logging_util import get_logger
 
@@ -57,8 +57,10 @@ class Consumer:
         while not self.should_stop:
             try:
                 await self.perform(await self.queue.get())
+            except CancelledError:
+                self.logger.warning("Cancelled task")
             except Exception as e:
-                self.logger.exception(f"Exception when calling callback : {e}")
+                self.logger.exception(e, True, f"Exception when calling callback on {self}: {e}")
             finally:
                 await self.consume_ends()
 
@@ -109,6 +111,9 @@ class Consumer:
         await self.start()
         self.create_task()
 
+    def __str__(self):
+        return f"{self.__class__.__name__} with callback: {self.callback.__name__}"
+
 
 class InternalConsumer(Consumer):
     def __init__(self):
