@@ -13,6 +13,7 @@
 #
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
+from octobot_channels.channels.channel import Channel
 
 
 async def create_all_subclasses_channel(channel_class, set_chan_method, **kwargs):
@@ -20,7 +21,8 @@ async def create_all_subclasses_channel(channel_class, set_chan_method, **kwargs
         await create_channel_instance(to_be_created_channel_class, set_chan_method, **kwargs)
 
 
-async def create_channel_instance(channel_class, set_chan_method, **kwargs):
+async def create_channel_instance(channel_class, set_chan_method, **kwargs) -> Channel:
     created_channel = channel_class(**kwargs)
     set_chan_method(created_channel, name=channel_class.get_name())
     await created_channel.start()
+    return created_channel
